"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _reactOutsideClickHandler = _interopRequireDefault(require("react-outside-click-handler"));

var _Transition = _interopRequireDefault(require("react-transition-group/Transition"));

var _Button = _interopRequireDefault(require("./Button"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _withStyles = require("../helpers/withStyles");

var _reactWithStyles = require("react-with-styles");

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const dropdownPropTypes = { ..._reactWithStyles.withStylesPropTypes,
  disabled: _propTypes.default.bool,
  loading: _propTypes.default.bool,
  fullWidth: _propTypes.default.bool,
  block: _propTypes.default.bool,
  bottom: _propTypes.default.bool,
  combo: _propTypes.default.bool,
  compact: _propTypes.default.bool,
  container: _propTypes.default.bool,
  icon: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.object]),
  inverse: _propTypes.default.bool,
  isOpen: _propTypes.default.bool,
  mono: _propTypes.default.bool,
  mountOnEnter: _propTypes.default.bool,
  unmountOnExit: _propTypes.default.bool,
  noBorder: _propTypes.default.bool,
  noSpacing: _propTypes.default.bool,
  shade: _propTypes.default.bool,
  soft: _propTypes.default.bool,
  primary: _propTypes.default.bool,
  rectangular: _propTypes.default.bool,
  removeIcon: _propTypes.default.bool,
  secondary: _propTypes.default.bool,
  side: _propTypes.default.bool,
  short: _propTypes.default.bool,
  transparent: _propTypes.default.bool,
  children: _propTypes.default.node,
  button: _propTypes.default.bool,
  label: _propTypes.default.oneOfType([_propTypes.default.string, _propTypes.default.object]),
  only: _propTypes.default.bool,
  relative: _propTypes.default.bool,
  left: _propTypes.default.bool,
  options: _propTypes.default.arrayOf(_propTypes.default.object),
  onSelectOption: _propTypes.default.func,
  closeOnSelect: _propTypes.default.bool,
  small: _propTypes.default.bool,
  large: _propTypes.default.bool,
  tall: _propTypes.default.bool,
  wide: _propTypes.default.bool
};
const dropdownMenuPropTypes = { ..._reactWithStyles.withStylesPropTypes,
  children: _propTypes.default.any.isRequired,
  left: _propTypes.default.bool,
  isOpen: _propTypes.default.bool,
  insideAButton: _propTypes.default.bool
};
const dropdownDefaultProps = {
  options: [],
  isOpen: false,
  removeIcon: false
};

class Dropdown extends _react.Component {
  constructor(props) {
    super(props);
    this.state = {
      isOpen: props.isOpen,
      closedByOutsideClick: false
    };
  }

  componentDidUpdate(prevProps, prevState) {
    if (prevProps.isOpen !== this.props.isOpen) {
      this.setState({
        isOpen: this.props.isOpen
      });
    }

    if (prevState.isOpen !== this.state.isOpen) {
      this.props.onToggleMenu && this.props.onToggleMenu(this.state.isOpen);
    }
  }

  toggleMenu() {
    this.setState(_ref => {
      let {
        isOpen,
        closedByOutsideClick
      } = _ref;
      return closedByOutsideClick && !isOpen ? {
        closedByOutsideClick: false
      } : {
        isOpen: !isOpen
      };
    });
  }

  closeMenu() {
    this.setState(_ref2 => {
      let {
        isOpen,
        closedByOutsideClick
      } = _ref2;
      return closedByOutsideClick && !isOpen ? {
        closedByOutsideClick: false
      } : {
        isOpen: false
      };
    });
  }

  onClickOutsideMenu() {
    this.setState(state => ({
      isOpen: false,
      closedByOutsideClick: state.isOpen
    }));
  }

  onSelectOption(option) {
    this.props.onSelectOption && this.props.onSelectOption(option);
    this.props.closeOnSelect && this.toggleMenu();
  }

  render() {
    const {
      styles,
      button,
      bottom,
      container,
      label,
      children,
      only,
      relative,
      left,
      options,
      disabled,
      loading,
      fullWidth,
      block,
      combo,
      compact,
      icon,
      inverse,
      mono,
      mountOnEnter,
      unmountOnExit,
      noBorder,
      noSpacing,
      shade,
      side,
      soft,
      shimmer,
      primary,
      rectangular,
      removeIcon,
      secondary,
      short,
      transparent,
      small,
      wide,
      tall,
      large
    } = this.props;
    return container ? /*#__PURE__*/_react.default.createElement("div", (0, _withStyles.css)(styles.dropdown__container, styles.dropdown__container_noSpacing, styles.dropdown__container_relative), /*#__PURE__*/_react.default.createElement("div", {
      onClick: () => this.toggleMenu()
    }, children), /*#__PURE__*/_react.default.createElement(DropdownMenuWithStyles, {
      isOpen: this.state.isOpen,
      onClickOutside: () => this.onClickOutsideMenu(),
      left: left,
      side: side,
      bottom: bottom,
      mountOnEnter: mountOnEnter,
      unmountOnExit: unmountOnExit
    }, /*#__PURE__*/_react.default.createElement("ul", (0, _withStyles.css)(styles.dropdown__list), options && options.map(option => {
      return /*#__PURE__*/_react.default.createElement("li", _extends({
        key: option.value
      }, (0, _withStyles.css)(styles.dropdown__list__item)), /*#__PURE__*/_react.default.createElement(_Button.default, {
        short: true,
        compact: true,
        inverse: true,
        noSpacing: true,
        block: true,
        onClick: () => this.onSelectOption(option)
      }, option.label));
    })))) : /*#__PURE__*/_react.default.createElement("div", (0, _withStyles.css)(styles.dropdown__container, button && styles.dropdown__container_asAButton, noSpacing && styles.dropdown__container_noSpacing, !combo && (container || button || only || relative) && styles.dropdown__container_relative), button ? /*#__PURE__*/_react.default.createElement(_Button.default, _extends({
      noSpacing: true,
      disabled: disabled,
      loading: loading,
      shimmer: shimmer,
      fullWidth: fullWidth,
      block: block,
      compact: compact,
      inverse: inverse,
      mono: mono,
      noBorder: noBorder,
      soft: soft,
      primary: primary,
      rectangular: rectangular,
      secondary: secondary,
      shade: shade,
      short: short,
      transparent: transparent,
      small: small,
      wide: wide,
      tall: tall,
      large: large,
      type: "button",
      onClick: () => this.toggleMenu()
    }, (0, _withStyles.css)(styles.dropdown, styles.dropdown_asAButton)), label, !removeIcon && (icon ? typeof label === 'string' ? /*#__PURE__*/_react.default.createElement(_Icon.default, {
      name: icon,
      primary: true,
      smaller: true,
      noPadding: true
    }) : icon : /*#__PURE__*/_react.default.createElement("svg", _extends({}, (0, _withStyles.css)(styles.dropdown__arrow, label && styles.dropdown__arrow_leftMarged, mono && styles.dropdown__arrow_mono, (soft || inverse || transparent) && styles.dropdown__arrow_primary, secondary && styles.dropdown__arrow_secondary), {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 10.4 6.3"
    }), /*#__PURE__*/_react.default.createElement("path", {
      d: "M5.2,6.3A.91.91,0,0,1,4.5,6L.3,1.8A1,1,0,0,1,.3.4,1,1,0,0,1,1.7.4L5.2,3.9,8.7.3a1,1,0,0,1,1.4,0,1,1,0,0,1,0,1.4L5.9,6a4.88,4.88,0,0,1-.7.3Z"
    })))) : /*#__PURE__*/_react.default.createElement("button", _extends({
      type: "button",
      onClick: () => this.toggleMenu()
    }, (0, _withStyles.css)(styles.dropdown, only && styles.dropdown_only)), /*#__PURE__*/_react.default.createElement("svg", _extends({}, (0, _withStyles.css)(styles.dropdown__arrow, mono && styles.dropdown__arrow_mono, (soft || inverse || transparent || primary) && styles.dropdown__arrow_primary, secondary && styles.dropdown__arrow_secondary), {
      xmlns: "http://www.w3.org/2000/svg",
      viewBox: "0 0 10.4 6.3"
    }), /*#__PURE__*/_react.default.createElement("path", {
      d: "M5.2,6.3A.91.91,0,0,1,4.5,6L.3,1.8A1,1,0,0,1,.3.4,1,1,0,0,1,1.7.4L5.2,3.9,8.7.3a1,1,0,0,1,1.4,0,1,1,0,0,1,0,1.4L5.9,6a4.88,4.88,0,0,1-.7.3Z"
    }))), /*#__PURE__*/_react.default.createElement(DropdownMenuWithStyles, {
      isOpen: this.state.isOpen,
      onClickOutside: () => this.onClickOutsideMenu(),
      insideAButton: button,
      combo: combo,
      left: left,
      side: side,
      bottom: bottom,
      mountOnEnter: mountOnEnter,
      unmountOnExit: unmountOnExit
    }, children ? children : /*#__PURE__*/_react.default.createElement("ul", (0, _withStyles.css)(styles.dropdown__list), options.map(option => {
      return /*#__PURE__*/_react.default.createElement("li", _extends({
        key: option.value
      }, (0, _withStyles.css)(styles.dropdown__list__item)), /*#__PURE__*/_react.default.createElement(_Button.default, {
        short: true,
        compact: true,
        inverse: true,
        noSpacing: true,
        block: true,
        onClick: () => this.onSelectOption(option)
      }, option.label));
    }))));
  }

}

class DropdownMenu extends _react.Component {
  render() {
    const {
      bottom,
      children,
      combo,
      left,
      isOpen,
      insideAButton,
      mountOnEnter,
      unmountOnExit,
      side,
      styles,
      onClickOutside
    } = this.props;
    return /*#__PURE__*/_react.default.createElement(_reactOutsideClickHandler.default, {
      onOutsideClick: () => onClickOutside()
    }, /*#__PURE__*/_react.default.createElement(_Transition.default, {
      in: isOpen,
      timeout: 300,
      mountOnEnter: mountOnEnter,
      unmountOnExit: unmountOnExit,
      onEnter: node => node.scrollTop
    }, state => /*#__PURE__*/_react.default.createElement("div", (0, _withStyles.css)(styles.dropdownMenu, !combo && insideAButton && styles.dropdownMenu_insideAButton, left && !side && styles.dropdownMenu_left, !left && !side && styles.dropdownMenu_right, left && side && styles.dropdownMenu_leftSide, !left && side && styles.dropdownMenu_rightSide, side && (bottom ? styles.dropdownMenu_sideBottom : styles.dropdownMenu_sideTop), (state === 'entering' || state === 'entered') && styles.dropdownMenu_entering, (state === 'exiting' || state === 'exited') && styles.dropdownMenu_exiting), children)));
  }

}

Dropdown.propTypes = dropdownPropTypes;
Dropdown.defaultProps = dropdownDefaultProps;
DropdownMenu.propTypes = dropdownMenuPropTypes;
const DropDownWithStyles = (0, _withStyles.withStyles)(_ref3 => {
  let {
    color,
    units
  } = _ref3;
  return {
    dropdown: {
      minWidth: units(1.5),
      minHeight: units(1.5),
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      outline: 'none',
      cursor: 'pointer',
      borderWidth: 0,
      background: color.transparent
    },
    dropdown_asAButton: {
      margin: 0
    },
    dropdown_only: {
      minWidth: units(2.5),
      height: units(2.5)
    },
    dropdown__arrow: {
      width: units(.5),
      fill: color.white
    },
    dropdown__arrow_leftMarged: {
      marginLeft: units(.75)
    },
    dropdown__arrow_rightMarged: {
      marginRight: units(.75)
    },
    dropdown__arrow_mono: {
      fill: color.black
    },
    dropdown__arrow_primary: {
      fill: color.primary
    },
    dropdown__arrow_secondary: {
      fill: color.secondary
    },
    dropdown_disabled: {
      opacity: .5,
      pointerEvents: 'none'
    },
    dropdown__container: {
      display: 'inline-block',
      boxSizing: 'border-box',
      maxWidth: '100%'
    },
    dropdown__container_relative: {
      position: 'relative'
    },
    dropdown__container_asAButton: {
      marginTop: 0,
      marginBottom: units(.5)
    },
    dropdown__container_noSpacing: {
      marginBottom: 0
    },
    dropdown__list: {
      margin: 0,
      padding: 0,
      listStyle: 'none'
    },
    dropdown__list__item: {}
  };
})(Dropdown);
const DropdownMenuWithStyles = (0, _withStyles.withStyles)(_ref4 => {
  let {
    color,
    units,
    radius
  } = _ref4;
  return {
    dropdownMenu: {
      position: 'absolute',
      marginTop: units(.25),
      top: '100%',
      backgroundColor: color.white,
      boxShadow: "0 ".concat(units(0.5), " ").concat(units(0.75), " ").concat(units(-0.45), " ").concat(color.shadow),
      padding: units(0.5),
      borderRadius: radius,
      borderWidth: 1,
      borderStyle: 'solid',
      borderColor: color.blueGrayLight,
      zIndex: 50,
      opacity: 0.01,
      transform: 'translate(0, -10%)',
      transition: 'opacity 200ms ease-out, transform 300ms ease-out',
      pointerEvents: 'none'
    },
    dropdownMenu_left: {
      left: 0
    },
    dropdownMenu_right: {
      right: 0
    },
    dropdownMenu_leftSide: {
      right: '100%',
      marginTop: 0,
      marginRight: units(.25)
    },
    dropdownMenu_rightSide: {
      left: '100%',
      marginTop: 0,
      marginLeft: units(.25)
    },
    dropdownMenu_sideBottom: {
      top: 'unset',
      bottom: 0
    },
    dropdownMenu_sideTop: {
      top: 0
    },
    dropdownMenu_insideAButton: {
      marginRight: units(0.125),
      marginLeft: units(0.125)
    },
    //transitions
    dropdownMenu_entering: {
      opacity: 1,
      transform: 'translate(0, 0)',
      transition: 'opacity 200ms ease-out, transform 300ms ease-out',
      pointerEvents: 'auto'
    },
    dropdownMenu_exiting: {
      opacity: 0.01,
      transform: 'translate(0, -10%)',
      transition: 'opacity 200ms ease-out, transform 300ms ease-out',
      pointerEvents: 'none'
    }
  };
}, {
  flushBefore: true
})(DropdownMenu);
var _default = DropDownWithStyles;
exports.default = _default;