"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _lodash = _interopRequireDefault(require("lodash"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _InputOnly = _interopRequireDefault(require("./InputOnly"));

var _Spacing = _interopRequireDefault(require("./Spacing"));

var _reactGoogleMaps = require("react-google-maps");

var _DrawingManager = _interopRequireDefault(require("react-google-maps/lib/components/drawing/DrawingManager"));

var _SearchBox = _interopRequireDefault(require("react-google-maps/lib/components/places/SearchBox"));

var _MarkerClusterer = _interopRequireDefault(require("react-google-maps/lib/components/addons/MarkerClusterer"));

var _CinnectaTheme = _interopRequireDefault(require("../themes/CinnectaTheme"));

var _MapCircle = _interopRequireDefault(require("./MapCircle"));

var _MapPolygon = _interopRequireDefault(require("./MapPolygon"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const propTypes = {
  children: _propTypes.default.any,
  defaultZoom: _propTypes.default.number,
  defaultCenter: _propTypes.default.object,
  defaultClickableIcons: _propTypes.default.bool,
  editMode: _propTypes.default.bool,
  isCenterMarkerVisible: _propTypes.default.bool,
  places: _propTypes.default.bool,
  removeMarkers: _propTypes.default.bool,
  shapes: _propTypes.default.array,
  shapesToEnframe: _propTypes.default.array
};
const defaultProps = {
  defaultZoom: 5,
  defaultCenter: {
    lat: -19.932231,
    lng: -43.9266687
  },
  isCenterMarkerVisible: false,
  defaultOptions: {
    streetViewControl: false,
    scaleControl: false,
    mapTypeControl: false,
    panControl: false,
    zoomControl: false,
    rotateControl: false,
    fullscreenControl: false,
    clickableIcons: false,
    disableDefaultUI: true,
    styles: _CinnectaTheme.default.map
  },
  defaultClickableIcons: false
};
const shapeOptions = {
  fillColor: '#ee430e',
  strokeColor: '#ee430e',
  strokeWeight: 1,
  fillOpacity: .3,
  strokeOpacity: .5
};

class Map extends _react.Component {
  constructor(props) {
    super(props);
    this.shapes = {};
    this.state = {
      google: null,
      pristine: true
    };
  }

  componentDidMount() {
    if (this.props.shapesToEnframe) {
      this.centerOnShapes(this.props.shapesToEnframe);
    }
  }

  componentDidUpdate(prevProps) {
    //if(prevProps.shapesToEnframe !== this.props.shapesToEnframe) {
    if (!_lodash.default.isEqual(prevProps.shapesToEnframe, this.props.shapesToEnframe)) {
      this.centerOnShapes(this.props.shapesToEnframe);
    }
  }

  mapLoaded(ref) {
    if (ref && this.state.pristine) {
      this.map = ref;
      const google = ref.props.google;
      this.props.onMapLoaded && this.props.onMapLoaded(google);

      if (this.state.google !== google) {
        this.setState({
          google,
          pristine: false
        }, () => this.centerOnShapes(this.props.shapes));
      }
    }
  }

  centerOnShapes(shapes) {
    const {
      google
    } = this.state;

    if (shapes && shapes.length > 0 && google) {
      let bounds = new google.maps.LatLngBounds();
      shapes.map(shape => {
        if (shape.type === 'circle') {
          const {
            lat,
            lng
          } = shape.center;
          const latLng = new google.maps.LatLng(lat, lng);
          const latOffset = shape.radius / 111320;
          const lngOffset = shape.radius / (40075000 * Math.cos(lat) / 360);
          const leftLatLng = new google.maps.LatLng(lat - latOffset, lng);
          const rightLatLng = new google.maps.LatLng(lat + latOffset, lng);
          const topLatLng = new google.maps.LatLng(lat, lng - lngOffset);
          const bottomLatLng = new google.maps.LatLng(lat, lng + lngOffset);
          bounds.extend(latLng);
          bounds.extend(leftLatLng);
          bounds.extend(rightLatLng);
          bounds.extend(topLatLng);
          bounds.extend(bottomLatLng);
        } else {
          shape.path.map(node => {
            const {
              lat,
              lng
            } = node;
            const latLng = new google.maps.LatLng(lat, lng);
            bounds.extend(latLng);
            return true;
          });
        }

        return true;
      });
      this.map.fitBounds(bounds);
    }
  }

  mapMoved() {
    this.props.onMapMoved && this.props.onMapMoved(this.map.getCenter()); //console.log('mapMoved: ' + JSON.stringify(this.map.getCenter()))
  }

  zoomChanged() {
    this.props.onZoomChanged && this.props.onZoomChanged(this.map.getZoom()); //console.log(this.map.getZoom())
  }

  placesChanged(places) {
    places && places[0] && this.map.fitBounds(places[0].geometry.viewport);
    this.props.onPlacesChanged && this.props.onPlacesChanged(places);
  }

  render() {
    const {
      apiKey,
      children,
      defaultCenter,
      isCenterMarkerVisible,
      editMode,
      highlightShape,
      onClickShape,
      onMouseOutShape,
      onMouseOverShape,
      places,
      removeMarkers,
      shapes,
      ...rest
    } = this.props;
    const {
      google
    } = this.state;
    return (
      /*#__PURE__*/
      //google &&
      _react.default.createElement(MapComponent, _extends({
        loadingElement: /*#__PURE__*/_react.default.createElement("div", {
          style: {
            height: "100%"
          }
        }),
        containerElement: /*#__PURE__*/_react.default.createElement("div", {
          style: {
            height: "100%"
          }
        }),
        mapElement: /*#__PURE__*/_react.default.createElement("div", {
          style: {
            height: "100%"
          }
        }),
        googleMapURL: "https://maps.googleapis.com/maps/api/js?key=".concat(apiKey, "&language=pt-BR&v=3.exp&libraries=geometry,drawing,places"),
        defaultCenter: defaultCenter,
        mapMoved: () => this.mapMoved(),
        zoomChanged: () => this.zoomChanged(),
        mapLoaded: ref => this.mapLoaded(ref)
      }, rest), isCenterMarkerVisible && /*#__PURE__*/_react.default.createElement(_reactGoogleMaps.Marker, {
        position: defaultCenter
      }), editMode && google && /*#__PURE__*/_react.default.createElement(_DrawingManager.default, {
        defaultDrawingMode: google.maps.drawing.OverlayType.CIRCLE,
        defaultOptions: {
          drawingControl: true,
          drawingControlOptions: {
            position: google.maps.ControlPosition.TOP_RIGHT,
            drawingModes: [google.maps.drawing.OverlayType.CIRCLE, google.maps.drawing.OverlayType.POLYGON]
          },
          circleOptions: {
            fillColor: "#68A7F0",
            strokeWeight: 0,
            clickable: false,
            editable: true,
            zIndex: 1
          },
          polygonOptions: {
            fillColor: "#68A7F0",
            strokeWeight: 0,
            clickable: false,
            editable: true,
            zIndex: 1
          }
        }
      }), places && google && /*#__PURE__*/_react.default.createElement(_SearchBox.default, {
        ref: ref => this.searchBox = ref,
        controlPosition: google.maps.ControlPosition.TOP_LEFT,
        onPlacesChanged: () => this.searchBox && this.placesChanged(this.searchBox.getPlaces()),
        onClose: () => {},
        showSearchBox: true,
        onSelectStory: () => {}
      }, /*#__PURE__*/_react.default.createElement("div", {
        style: {
          maxWidth: 540,
          width: '100%',
          opacity: .9
        }
      }, /*#__PURE__*/_react.default.createElement(_Spacing.default, {
        top: 1,
        left: 1
      }, /*#__PURE__*/_react.default.createElement(_InputOnly.default, {
        floating: true,
        type: "text",
        placeholder: "Pesquise no mapa...",
        name: "googlePlaces"
      })))), /*#__PURE__*/_react.default.createElement(_MarkerClusterer.default, {
        averageCenter: true,
        enableRetinaIcons: true,
        gridSize: 60,
        maxZoom: 13,
        minimumClusterSize: 1
      }, shapes && shapes.map(shape => {
        if (shape.type === 'circle') {
          return /*#__PURE__*/_react.default.createElement(_MapCircle.default, {
            key: shape.id //ref={ref => this.shapes[shape.id] = ref}
            ,
            center: shape.center,
            radius: shape.radius,
            editable: shape.editable,
            draggable: shape.draggable,
            options: { ...shapeOptions,
              ...(shape.color && {
                fillColor: shape.color
              }),
              ...(highlightShape === shape.id && {
                fillColor: 'yellow'
              }),
              ...(shape.color && {
                strokeColor: shape.color
              }),
              ...(shape.strokeColor && {
                strokeColor: shape.strokeColor
              }),
              ...(shape.opacity && {
                fillOpacity: shape.opacity,
                strokeOpacity: shape.opacity
              }),
              ...(shape.strokeOpacity && {
                strokeOpacity: shape.strokeOpacity
              })
            },
            removeMarker: removeMarkers,
            onClick: () => onClickShape && onClickShape(shape),
            onMouseOver: () => onMouseOverShape && onMouseOverShape(shape),
            onMouseOut: () => onMouseOutShape && onMouseOutShape(shape)
          });
        } else {
          return /*#__PURE__*/_react.default.createElement(_MapPolygon.default, {
            key: shape.id //ref={ref => this.shapes[shape.id] = ref}
            ,
            path: shape.path,
            options: { ...shapeOptions,
              ...(shape.color && {
                fillColor: shape.color
              }),
              ...(highlightShape === shape.id && {
                fillColor: 'yellow'
              }),
              ...(shape.color && {
                strokeColor: shape.color
              }),
              ...(shape.strokeColor && {
                strokeColor: shape.strokeColor
              }),
              ...(shape.opacity && {
                fillOpacity: shape.opacity,
                strokeOpacity: shape.opacity
              }),
              ...(shape.strokeOpacity && {
                strokeOpacity: shape.strokeOpacity
              })
            },
            removeMarker: removeMarkers,
            onClick: () => onClickShape && onClickShape(shape),
            onMouseOver: () => onMouseOverShape && onMouseOverShape(shape),
            onMouseOut: () => onMouseOutShape && onMouseOutShape(shape)
          });
        }
      }), children))
    );
  }

}

Map.propTypes = propTypes;
Map.defaultProps = defaultProps;
const MapComponent = (0, _reactGoogleMaps.withScriptjs)((0, _reactGoogleMaps.withGoogleMap)(_ref => {
  let {
    defaultCenter,
    mapMoved,
    mapLoaded,
    zoomChanged,
    ...props
  } = _ref;
  return /*#__PURE__*/_react.default.createElement(_reactGoogleMaps.GoogleMap, _extends({
    defaultCenter: defaultCenter,
    onIdle: mapMoved,
    ref: mapLoaded,
    onZoomChanged: zoomChanged,
    google: window.google
  }, props), props.children);
}));
var _default = Map;
exports.default = _default;