"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withBreakpoints = exports.ResponsiveWrapper = exports.ResponsiveConsumer = exports.Responsive = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _breakpoints = require("../helpers/breakpoints");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const initialBreakpoint = {
  name: 'default',
  value: 0
};

const {
  Provider,
  Consumer
} = /*#__PURE__*/_react.default.createContext(initialBreakpoint);

const ResponsiveConsumer = Consumer;
exports.ResponsiveConsumer = ResponsiveConsumer;

const withBreakpoints = Comp => props => /*#__PURE__*/_react.default.createElement(ResponsiveConsumer, null, breakpoint => /*#__PURE__*/_react.default.createElement(Comp, _extends({
  breakpoint: breakpoint,
  isGreaterThan: value => breakpointIsGreaterThan(value, breakpoint.value),
  isLessThan: value => breakpointIsLessThan(value, breakpoint.value)
}, props)));

exports.withBreakpoints = withBreakpoints;

class ResponsiveWrapper extends _react.Component {
  constructor(props) {
    super(props);
    this.state = { ...initialBreakpoint
    };
    this.mediaQueries = [];
  }

  componentDidMount() {
    this.mediaQueries = Object.keys(_breakpoints.breakpoints).map(key => {
      const query = window.matchMedia("(min-width: ".concat(_breakpoints.breakpoints[key], "px)"));
      query.breakpoint = _breakpoints.breakpoints[key];
      query.name = key;
      query.addListener(() => this.dispatchActiveQuery());
      return query;
    });
    this.dispatchActiveQuery();
  }

  componentWillUnmount() {
    for (let query of this.mediaQueries) {
      query.removeListener(() => this.dispatchActiveQuery());
    }
  }

  dispatchActiveQuery() {
    const activeQuery = this.mediaQueries.reduce((prev, curr) => {
      return curr.matches ? curr : prev && prev.matches ? prev : null;
    });
    const breakpointName = activeQuery ? activeQuery.name : 'default';
    const breakpointSize = activeQuery && activeQuery.breakpoint;
    this.setState({
      name: breakpointName,
      value: breakpointSize
    });
  }

  render() {
    return /*#__PURE__*/_react.default.createElement(Provider, {
      value: { ...this.state
      }
    }, /*#__PURE__*/_react.default.createElement(_react.Fragment, null, this.props.children));
  }

}

exports.ResponsiveWrapper = ResponsiveWrapper;
const propTypes = {
  unmount: _propTypes.default.bool,
  showFor: _propTypes.default.oneOf(['small', 'medium', 'large', 'xlarge']),
  hideFor: _propTypes.default.oneOf(['small', 'medium', 'large', 'xlarge']),
  children: _propTypes.default.any
};

class Responsive extends _react.Component {
  render() {
    const {
      unmount,
      showFor,
      hideFor,
      children
    } = this.props;

    const content = breakpoint => {
      if (showFor && breakpointIsLessThan(showFor, breakpoint.value) || hideFor && breakpointIsGreaterThan(hideFor, breakpoint.value)) {
        if (unmount) {
          return null;
        } else {
          return /*#__PURE__*/_react.default.createElement("div", {
            style: {
              display: 'none'
            }
          }, children);
        }
      } else {
        return children;
      }
    };

    return /*#__PURE__*/_react.default.createElement(Consumer, null, breakpoint => content(breakpoint));
  }

}

exports.Responsive = Responsive;
Responsive.propTypes = propTypes;

const breakpointIsGreaterThan = (breakpointToCompare, currentBreakpointSize) => {
  const comparison = typeof breakpointToCompare === 'string' ? _breakpoints.breakpoints[breakpointToCompare] : breakpointToCompare;
  return currentBreakpointSize === null || currentBreakpointSize >= comparison;
};

const breakpointIsLessThan = (breakpointToCompare, currentBreakpointSize) => {
  const comparison = typeof breakpointToCompare === 'string' ? _breakpoints.breakpoints[breakpointToCompare] : breakpointToCompare;
  return currentBreakpointSize !== null && currentBreakpointSize < comparison;
};