"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _lodash = _interopRequireDefault(require("lodash"));

var _moment = _interopRequireDefault(require("moment"));

var _Dropdown = _interopRequireDefault(require("./Dropdown"));

var _Grid = _interopRequireDefault(require("./Grid"));

var _Cell = _interopRequireDefault(require("./Cell"));

var _Responsive = require("./Responsive");

var _Visibility = _interopRequireDefault(require("./Visibility"));

var _CheckboxOnly = _interopRequireDefault(require("./CheckboxOnly"));

var _InputOnly = _interopRequireDefault(require("./InputOnly"));

var _ThrottledTextInput = _interopRequireDefault(require("./ThrottledTextInput"));

var _Icon = _interopRequireDefault(require("./Icon"));

var _Text = _interopRequireDefault(require("./Text"));

var _Spacing = _interopRequireDefault(require("./Spacing"));

var _SummaryItem = _interopRequireDefault(require("./SummaryItem"));

var _withStyles = require("../helpers/withStyles");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const propTypes = {
  data: _propTypes.default.array.isRequired,
  loading: _propTypes.default.bool,
  dateFormat: _propTypes.default.string,
  divided: _propTypes.default.bool,
  searchPlaceholder: _propTypes.default.string,
  maxResults: _propTypes.default.number,
  noResultComponent: _propTypes.default.object,
  customActions: _propTypes.default.any,
  sortOptions: _propTypes.default.arrayOf(_propTypes.default.objectOf(_propTypes.default.string)),
  filterFor: _propTypes.default.arrayOf(_propTypes.default.oneOf(['title', 'description'])),
  clean: _propTypes.default.bool,
  onItemAction: _propTypes.default.func,
  paginate: _propTypes.default.bool,
  icons: _propTypes.default.arrayOf(_propTypes.default.string),
  withFilter: _propTypes.default.bool,
  sortable: _propTypes.default.bool,
  selectableItems: _propTypes.default.bool,
  hideComboButton: _propTypes.default.bool
};
const defaultProps = {
  data: [],
  dateFormat: 'YYYY-MM-DD hh:mm:ss',
  maxResults: 0,
  noResultComponent: /*#__PURE__*/_react.default.createElement(_Text.default, null, "Nenhum resultado..."),
  searchPlaceholder: 'buscar...',
  sortOptions: [{
    label: 'Data de criação',
    value: 'createdAt'
  }, {
    label: 'Última atualização',
    value: 'updatedAt'
  }, {
    label: 'Título',
    value: 'title'
  }],
  filterFor: ['title', 'description']
};

class SummaryList extends _react.Component {
  constructor(props) {
    super(props);
    this.state = {
      checked: [],
      sort: props.sortOptions ? props.sortOptions[0] : null,
      filterString: ''
    };
  }

  filterList(data) {
    const {
      filterFor,
      withFilter
    } = this.props;
    const {
      filterString
    } = this.state;

    if (withFilter && Array.isArray(filterFor) && filterFor.length > 0 && filterString.length > 2) {
      return data.filter(item => {
        return filterFor.some(filter => {
          try {
            return item[filter].toLowerCase().search(filterString.toLowerCase()) !== -1;
          } catch (e) {
            return false;
          }
        });
      });
    }

    return data;
  }

  sortList(data) {
    const {
      sort
    } = this.state;

    if (sort.value && data && Array.isArray(data) && data.length > 0 && data[0][sort.value] != null) {
      const isTime = (0, _moment.default)(data[0][sort.value], this.props.dateFormat).isValid();
      return _lodash.default.orderBy(data, item => {
        return isTime ? (0, _moment.default)(item[sort.value], this.props.dateFormat).valueOf() : item[sort.value];
      }, isTime ? ['desc'] : ['asc']);
    }

    return data;
  }

  toggleItem(id) {
    let checked = [...this.state.checked];

    if (checked.includes(id)) {
      checked.splice(id, 1);
    } else {
      checked.push(id);
    }

    this.setState({
      checked
    });
  }

  render() {
    const {
      data,
      loading,
      divided,
      searchPlaceholder,
      noResultComponent,
      maxResults,
      customActions,
      sortOptions,
      clean,
      paginate,
      onItemAction,
      icons,
      withFilter,
      selectableItems,
      sortable,
      styles,
      css,
      hideComboButton
    } = this.props;
    const {
      checked
    } = this.state;
    const listPlaceholder = loading ? /*#__PURE__*/_react.default.createElement(_react.Fragment, null, [...Array(maxResults ? maxResults : 10)].map((e, i) => /*#__PURE__*/_react.default.createElement(_SummaryItem.default, {
      divided: divided,
      key: i,
      loading: true
    }))) : /*#__PURE__*/_react.default.createElement("div", null, noResultComponent);
    return /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList, clean && styles.summaryList_clean, checked.length > 0 && styles.summaryList_edit), (withFilter || sortable || selectableItems) && /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList__header), /*#__PURE__*/_react.default.createElement(_Grid.default, {
      resetSpacing: true
    }, selectableItems && /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, /*#__PURE__*/_react.default.createElement(_CheckboxOnly.default, null)), withFilter && /*#__PURE__*/_react.default.createElement(_Responsive.Responsive, {
      showFor: "large"
    }, /*#__PURE__*/_react.default.createElement(_Cell.default, {
      auto: true
    }, /*#__PURE__*/_react.default.createElement("div", css(styles.summaryList__header__filter), /*#__PURE__*/_react.default.createElement(_ThrottledTextInput.default, {
      debouncedOnChange: value => this.setState({
        filterString: value
      }),
      debounceTimeoutMs: 500
    }, /*#__PURE__*/_react.default.createElement(_InputOnly.default, {
      name: "filterInput",
      placeholder: searchPlaceholder,
      shimmer: loading,
      prefix: /*#__PURE__*/_react.default.createElement(_Icon.default, {
        name: "search"
      }),
      removeMargins: true
    }))))), customActions && /*#__PURE__*/_react.default.createElement(_Responsive.Responsive, {
      showFor: "large"
    }, /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, customActions)), sortable && /*#__PURE__*/_react.default.createElement(_Cell.default, {
      shrink: true
    }, /*#__PURE__*/_react.default.createElement("span", null, /*#__PURE__*/_react.default.createElement(_Text.default, {
      small: true,
      inline: true,
      loading: loading
    }, "Ordernar por:"), /*#__PURE__*/_react.default.createElement(_Spacing.default, {
      left: .1,
      inline: true
    }, /*#__PURE__*/_react.default.createElement(_Dropdown.default, {
      button: true,
      label: this.state.sort && this.state.sort.label,
      options: sortOptions,
      onSelectOption: value => this.setState({
        sort: value
      }),
      shimmer: loading,
      loading: loading,
      closeOnSelect: true,
      inverse: true,
      compact: true,
      noSpacing: true
    })))))), /*#__PURE__*/_react.default.createElement("ul", css(styles.summaryList__list), data.length < 1 ? listPlaceholder : this.sortList(this.filterList(data)).map(item => {
      if (item) {
        return /*#__PURE__*/_react.default.createElement(_SummaryItem.default, {
          key: item.id,
          item: loading ? {} : item,
          clean: clean,
          divided: divided,
          checked: checked.includes(item.id),
          onAction: action => onItemAction(action, item.id),
          onChange: () => this.toggleItem(item.id),
          loading: loading,
          selectable: selectableItems,
          hideComboButton: hideComboButton
        }, /*#__PURE__*/_react.default.createElement(_react.Fragment, null, item.custom, icons && !item.custom ? /*#__PURE__*/_react.default.createElement(_react.Fragment, null, item.icons.map(icon => /*#__PURE__*/_react.default.createElement("i", {
          className: "icon-".concat(icon),
          key: icon
        }))) : null));
      } else {
        return false;
      }
    })), /*#__PURE__*/_react.default.createElement(_Visibility.default, {
      unmount: true,
      showIf: paginate
    }, "pagina\xE7\xE3o"));
  }

}

SummaryList.propTypes = propTypes;
SummaryList.defaultProps = defaultProps;
const SummaryListWithStyles = (0, _withStyles.withStyles)(_ref => {
  let {
    units,
    color,
    breakpoint
  } = _ref;
  return {
    summaryList: {},
    summaryList_clean: {
      [breakpoint.mediumAndAbove]: {//paddingLeft: units(2),
        //paddingRight: units(2),
      }
    },
    summaryList_edit: {},
    summaryList__header: {
      paddingTop: 0,
      paddingBottom: units(1.5),
      borderBottomWidth: 1,
      borderBottomStyle: 'solid',
      borderBottomColor: color.blueGrayLight
    },
    summaryList__header__filter: {
      maxWidth: units(24)
    },
    summaryList__list: {
      margin: 0,
      padding: 0,
      listStyle: 'none'
    }
  };
})(SummaryList);
var _default = SummaryListWithStyles;
exports.default = _default;