"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.required = exports.phoneNumber = exports.number = exports.minValue = exports.minLength = exports.maxLength = exports.isJson = exports.email = exports.alphaNumeric = void 0;

const required = value => value || value === 0 ? undefined : 'Campo obrigatório';

exports.required = required;

const maxLength = max => value => value && value.length > max ? "Campo deve conter ".concat(max, " caracteres ou menos") : undefined;

exports.maxLength = maxLength;

const minLength = min => value => value && value.length < min ? "Campo deve conter ".concat(min, " caracteres ou mais") : undefined;

exports.minLength = minLength;

const number = value => value && isNaN(Number(value)) ? 'Apenas números' : undefined;

exports.number = number;

const minValue = min => value => value && value < min ? "Valor m\xEDnimo: ".concat(min) : undefined;

exports.minValue = minValue;

const email = value => value && !/^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,4}$/i.test(value) ? 'Endereço de email inválido' : undefined;

exports.email = email;

const alphaNumeric = value => value && /[^a-zA-Z0-9 ]/i.test(value) ? 'Apenas caracteres alfanuméricos' : undefined;

exports.alphaNumeric = alphaNumeric;

const phoneNumber = value => value && !/^(0|[1-9][0-9]{9})$/i.test(value) ? 'Telefone inválido' : undefined;

exports.phoneNumber = phoneNumber;

const isJson = value => {
  if (value) {
    try {
      JSON.parse(value);
      return undefined;
    } catch (e) {
      return 'JSON inválido';
    }
  }
};

exports.isJson = isJson;